@@ -3,7 +3,7 @@
  Copyright(c) 2014 Jasem Mutlaq. All rights reserved.
 
  The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi.
- The transformations are based on the paper Matrix Method for Coodinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
+ The transformations are based on the paper Matrix Method for Coordinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
@@ -63,7 +63,7 @@ class TCP;
 
    Developers need to subclass INDI::Dome to implement any driver for Domes within INDI.
 
-  \note The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi. The transformations are based on the paper Matrix Method for Coodinates
+  \note The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi. The transformations are based on the paper Matrix Method for Coordinates
  Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
 
 \author Jasem Mutlaq
@@ -155,7 +155,7 @@ class Dome : public DefaultDevice
         {
             DOME_CAN_ABORT          = 1 << 0, /*!< Can the dome motion be aborted? */
             DOME_CAN_ABS_MOVE       = 1 << 1, /*!< Can the dome move to an absolute azimuth position? */
-            DOME_CAN_REL_MOVE       = 1 << 2, /*!< Can the dome move to a relative position a number of degrees away from current position? Positive degress is Clockwise direction. Negative Degrees is counter clock wise direction */
+            DOME_CAN_REL_MOVE       = 1 << 2, /*!< Can the dome move to a relative position a number of degrees away from current position? Positive degrees is Clockwise direction. Negative Degrees is counter clock wise direction */
             DOME_CAN_PARK           = 1 << 3, /*!< Can the dome park and unpark itself? */
             DOME_CAN_SYNC           = 1 << 4, /*!< Can the dome sync to arbitrary position? */
             DOME_HAS_SHUTTER        = 1 << 5, /*!< Does the dome has a shutter than can be opened and closed electronically? */
@@ -420,13 +420,13 @@ class Dome : public DefaultDevice
 
         /**
              * @brief SetRAPark Set current AZ parking position. The data park file (stored in ~/.indi/ParkData.xml) is updated in the process.
-             * @param value current Axis 1 value (AZ either in angles or encoder values as specificed by the DomeParkData type).
+             * @param value current Axis 1 value (AZ either in angles or encoder values as specified by the DomeParkData type).
              */
         void SetAxis1Park(double value);
 
         /**
              * @brief SetAxis1Park Set default AZ parking position.
-             * @param value Default Axis 1 value (AZ either in angles or encoder values as specificed by the DomeParkData type).
+             * @param value Default Axis 1 value (AZ either in angles or encoder values as specified by the DomeParkData type).
              */
         void SetAxis1ParkDefault(double steps);
 
@@ -524,70 +524,47 @@ class Dome : public DefaultDevice
         double Csc(double x);
         double Sec(double x);
 
-        INumberVectorProperty DomeSpeedNP;
-        INumber DomeSpeedN[1];
+        INDI::PropertyNumber DomeSpeedNP {1};
 
-        ISwitchVectorProperty DomeMotionSP;
-        ISwitch DomeMotionS[2];
+        INDI::PropertySwitch DomeMotionSP {2};
 
-        INumberVectorProperty DomeAbsPosNP;
-        INumber DomeAbsPosN[1];
+        INDI::PropertyNumber DomeAbsPosNP {1};
 
-        INumberVectorProperty DomeRelPosNP;
-        INumber DomeRelPosN[1];
+        INDI::PropertyNumber DomeRelPosNP {1};
 
-        ISwitchVectorProperty AbortSP;
-        ISwitch AbortS[1];
+        INDI::PropertySwitch AbortSP {1};
 
-        INumberVectorProperty DomeParamNP;
-        INumber DomeParamN[1];
+        INDI::PropertyNumber DomeParamNP {1};
 
-        INumberVectorProperty DomeSyncNP;
-        INumber DomeSyncN[1];
+        INDI::PropertyNumber DomeSyncNP {1};
 
-        ISwitchVectorProperty DomeShutterSP;
-        ISwitch DomeShutterS[2];
+        INDI::PropertySwitch DomeShutterSP {2};
 
-        ISwitchVectorProperty ParkSP;
-        ISwitch ParkS[2];
+        INDI::PropertySwitch ParkSP {2};
 
-        INumber ParkPositionN[1];
-        INumberVectorProperty ParkPositionNP;
+        INDI::PropertyNumber ParkPositionNP {1};
 
-        ISwitch ParkOptionS[3];
-        ISwitchVectorProperty ParkOptionSP;
+        INDI::PropertySwitch ParkOptionSP {3};
 
-        //        ISwitch AutoParkS[2];
-        //        ISwitchVectorProperty AutoParkSP;
-
-        uint32_t capability;
-        DomeParkData parkDataType;
-
-        ITextVectorProperty ActiveDeviceTP;
-        IText ActiveDeviceT[1] {};
+        INDI::PropertyText ActiveDeviceTP {1};
 
         // Switch to lock id mount is unparked
-        ISwitchVectorProperty MountPolicySP;
-        ISwitch MountPolicyS[2];
+        INDI::PropertySwitch MountPolicySP {2};
 
         // Shutter control on Park/Unpark
-        ISwitchVectorProperty ShutterParkPolicySP;
-        ISwitch ShutterParkPolicyS[2];
+        INDI::PropertySwitch ShutterParkPolicySP {2};
         enum
         {
             SHUTTER_CLOSE_ON_PARK,
             SHUTTER_OPEN_ON_UNPARK,
         };
 
-        INumber PresetN[3];
-        INumberVectorProperty PresetNP;
-        ISwitch PresetGotoS[3];
-        ISwitchVectorProperty PresetGotoSP;
-        INumber DomeMeasurementsN[6];
-        INumberVectorProperty DomeMeasurementsNP;
+        INDI::PropertyNumber PresetNP {3};
+        INDI::PropertySwitch PresetGotoSP {3};
 
-        ISwitchVectorProperty OTASideSP;
-        ISwitch OTASideS[5];
+        INDI::PropertyNumber DomeMeasurementsNP {6};
+
+        INDI::PropertySwitch OTASideSP {5};
         // 0 is East, 1 is West, 2 is as reported by mout, 3 as deducted by Hour Angle
         // 4 ignore pier side and perform as in a fork mount
         enum
@@ -600,16 +577,16 @@ class Dome : public DefaultDevice
         };
 
         int mountOTASide = 0; // Side of the telescope with respect of the mount, 1: west, -1: east, 0 not reported
-        ISwitchVectorProperty DomeAutoSyncSP;
-        ISwitch DomeAutoSyncS[2];
+        INDI::PropertySwitch DomeAutoSyncSP {2};
 
-        // Backlash toogle
-        ISwitchVectorProperty DomeBacklashSP;
-        ISwitch DomeBacklashS[2];
+        // Backlash toggle
+        INDI::PropertySwitch DomeBacklashSP {2};
 
         // Backlash steps
-        INumberVectorProperty DomeBacklashNP;
-        INumber DomeBacklashN[1];
+        INDI::PropertyNumber DomeBacklashNP {1};
+
+        uint32_t capability;
+        DomeParkData parkDataType;
 
         double prev_az, prev_alt, prev_ra, prev_dec;
 
